@@ -4,7 +4,7 @@
 <context>
     <name>ActionPackInternal</name>
     <message>
-        <location filename="../actions/actionpackinternal/actionpackinternal.h" line="77"/>
+        <location filename="../actions/actionpackinternal/actionpackinternal.h" line="74"/>
         <source>Internal actions</source>
         <translation>Actions internes</translation>
     </message>
@@ -12,12 +12,12 @@
 <context>
     <name>Actions::BeginProcedureDefinition</name>
     <message>
-        <location filename="../actions/actionpackinternal/actions/beginproceduredefinition.h" line="44"/>
+        <location filename="../actions/actionpackinternal/actions/beginproceduredefinition.h" line="43"/>
         <source>Name</source>
         <translation>Nom</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/beginproceduredefinition.h" line="45"/>
+        <location filename="../actions/actionpackinternal/actions/beginproceduredefinition.h" line="44"/>
         <source>The name of the procedure</source>
         <translation>Le nom de la procédure</translation>
     </message>
@@ -29,12 +29,12 @@
 <context>
     <name>Actions::CallProcedureDefinition</name>
     <message>
-        <location filename="../actions/actionpackinternal/actions/callproceduredefinition.h" line="44"/>
+        <location filename="../actions/actionpackinternal/actions/callproceduredefinition.h" line="43"/>
         <source>Name</source>
         <translation>Nom</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/callproceduredefinition.h" line="45"/>
+        <location filename="../actions/actionpackinternal/actions/callproceduredefinition.h" line="44"/>
         <source>The name of the procedure to call</source>
         <translation>Le nom de la procédure à appeler</translation>
     </message>
@@ -42,12 +42,12 @@
 <context>
     <name>Actions::CodeDefinition</name>
     <message>
-        <location filename="../actions/actionpackinternal/actions/codedefinition.h" line="44"/>
+        <location filename="../actions/actionpackinternal/actions/codedefinition.h" line="43"/>
         <source>Code</source>
         <translation>Code</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/codedefinition.h" line="45"/>
+        <location filename="../actions/actionpackinternal/actions/codedefinition.h" line="44"/>
         <source>The code to evaluate</source>
         <translation>Le code à évaluer</translation>
     </message>
@@ -55,22 +55,22 @@
 <context>
     <name>Actions::ConsoleDefinition</name>
     <message>
-        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="47"/>
+        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="46"/>
         <source>Text</source>
         <translation>Texte</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="48"/>
+        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="47"/>
         <source>The text to write</source>
         <translation>Le texte à écrire</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="51"/>
+        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="49"/>
         <source>Output</source>
         <translation>Sortie</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="52"/>
+        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="50"/>
         <source>The console output</source>
         <translation>Le type de sortie</translation>
     </message>
@@ -78,7 +78,7 @@
 <context>
     <name>Actions::EndProcedureInstance</name>
     <message>
-        <location filename="../actions/actionpackinternal/actions/endprocedureinstance.h" line="43"/>
+        <location filename="../actions/actionpackinternal/actions/endprocedureinstance.h" line="42"/>
         <source>End procedure reached without a call</source>
         <translation>Fin de procédure atteint sans procédure appelée</translation>
     </message>
@@ -86,58 +86,62 @@
 <context>
     <name>Actions::GotoDefinition</name>
     <message>
-        <location filename="../actions/actionpackinternal/actions/gotodefinition.h" line="44"/>
+        <location filename="../actions/actionpackinternal/actions/gotodefinition.h" line="43"/>
         <source>Line</source>
         <translation>Ligne</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/gotodefinition.h" line="45"/>
+        <location filename="../actions/actionpackinternal/actions/gotodefinition.h" line="44"/>
         <source>The line (or label) to go to</source>
-        <translation>La ligne (ou le label) à aller</translation>
+        <translation>La ligne (ou l&apos;étiquette) où aller</translation>
     </message>
 </context>
 <context>
     <name>Actions::LoopDefinition</name>
     <message>
-        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="47"/>
+        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="46"/>
         <source>Line</source>
         <translation>Ligne</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="48"/>
+        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="47"/>
         <source>The line (or label) to go to</source>
-        <translation>La ligne (ou le label) à aller</translation>
+        <translation>La ligne (ou l&apos;étiquette) où aller</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="51"/>
+        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="49"/>
         <source>Count</source>
         <translation>Nombre de fois</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="52"/>
-        <source>The amount of times (evaluated the first time)</source>
+        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="50"/>
+        <source>The number of times (evaluated the first time)</source>
         <translation>Le nombre de fois (évalué la première fois)</translation>
     </message>
+    <message>
+        <source>The amount of times (evaluated the first time)</source>
+        <translation type="vanished">Le nombre de fois (évalué la première fois)</translation>
+    </message>
 </context>
 <context>
     <name>Actions::PauseDefinition</name>
     <message>
-        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="49"/>
+        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="48"/>
         <source>Duration</source>
         <translation>Durée</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="50"/>
+        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="49"/>
         <source>The duration of the pause</source>
         <translation>La durée de la pause</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="56"/>
+        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="54"/>
         <source>Unit</source>
         <translation>Unité</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="57"/>
+        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="55"/>
         <source>The pause duration unit</source>
         <translation>L&apos;unité de durée de pause</translation>
     </message>
@@ -150,7 +154,7 @@
 <context>
     <name>Actions::PauseInstance</name>
     <message>
-        <location filename="../actions/actionpackinternal/actions/pauseinstance.h" line="66"/>
+        <location filename="../actions/actionpackinternal/actions/pauseinstance.h" line="65"/>
         <source>Invalid pause duration</source>
         <translation>Durée de pause incorrecte</translation>
     </message>
@@ -158,12 +162,12 @@
 <context>
     <name>Actions::TimeConditionDefinition</name>
     <message>
-        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="45"/>
+        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="44"/>
         <source>Date</source>
         <translation>Date</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="46"/>
+        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="45"/>
         <source>The date to compare</source>
         <translation>La date à comparer</translation>
     </message>
@@ -172,27 +176,27 @@
         <translation type="vanished">Si avant</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="49"/>
+        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="47"/>
         <source>If in the past</source>
         <translation>Si dans le passé</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="50"/>
+        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="48"/>
         <source>What to do if the date is in the past</source>
         <translation>Ce qui doit être fait si la date appartient au passé</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="53"/>
+        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="50"/>
         <source>If now</source>
         <translation>Si maintenant</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="54"/>
+        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="51"/>
         <source>What to do if the date is the current date</source>
         <translation>Ce qui doit être fait si la date est la date actuelle</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="57"/>
+        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="53"/>
         <source>If in the future</source>
         <translation>Si dans le futur</translation>
     </message>
@@ -201,7 +205,7 @@
         <translation type="vanished">Si après</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="58"/>
+        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="54"/>
         <source>What to do if the date is in the future</source>
         <translation>Ce qui doit être fait si la date appartient au futur</translation>
     </message>
@@ -209,7 +213,7 @@
 <context>
     <name>Actions::TimeConditionInstance</name>
     <message>
-        <location filename="../actions/actionpackinternal/actions/timeconditioninstance.h" line="49"/>
+        <location filename="../actions/actionpackinternal/actions/timeconditioninstance.h" line="48"/>
         <source>Invalid date</source>
         <translation>Date incorrecte</translation>
     </message>
@@ -217,52 +221,52 @@
 <context>
     <name>Actions::VariableConditionDefinition</name>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="49"/>
+        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="48"/>
         <source>Variable</source>
         <translation>Variable</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="51"/>
+        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="50"/>
         <source>The variable to compare</source>
         <translation>La variable à comparer</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="54"/>
+        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="52"/>
         <source>Comparison</source>
         <translation>Comparaison</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="55"/>
+        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="53"/>
         <source>The comparison</source>
         <translation>La comparaison</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="60"/>
+        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="57"/>
         <source>Value</source>
         <translation>Valeur</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="61"/>
+        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="58"/>
         <source>The value</source>
         <translation>La valeur</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="64"/>
+        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="60"/>
         <source>If true</source>
         <translation>Si vrai</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="65"/>
+        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="61"/>
         <source>What to do if the comparison result is true</source>
         <translation>Ce qui doit être fait si le résultat de la comparaison est vrai</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="68"/>
+        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="63"/>
         <source>If false</source>
         <translation>Si faux</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="69"/>
+        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="64"/>
         <source>What to do if the comparison result is false</source>
         <translation>Ce qui doit être fait si le résultat de la comparaison est faux</translation>
     </message>
@@ -290,7 +294,7 @@
         <translation type="obsolete">Variable nulle</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.h" line="70"/>
+        <location filename="../actions/actionpackinternal/actions/variableconditioninstance.h" line="69"/>
         <source>Invalid variable</source>
         <translation>Variable invalide</translation>
     </message>
@@ -298,17 +302,17 @@
 <context>
     <name>Actions::VariableDefinition</name>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="51"/>
+        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="50"/>
         <source>Variable</source>
         <translation>Variable</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="53"/>
+        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="52"/>
         <source>The variable name</source>
         <translation>Le nom de la variable</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="70"/>
+        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="67"/>
         <source>Value</source>
         <translation>Valeur</translation>
     </message>
@@ -317,34 +321,34 @@
         <translation type="obsolete">La nouvelle valeur de la variable</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="56"/>
+        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="54"/>
         <source>Type</source>
         <translation>Type</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="57"/>
+        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="55"/>
         <source>The variable type</source>
         <translation>Le type de la variable</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="71"/>
-        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="83"/>
-        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="95"/>
+        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="68"/>
+        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="77"/>
+        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="86"/>
         <source>The variables new value</source>
         <translation>La nouvelle valeur de la variable</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="82"/>
+        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="76"/>
         <source>Color</source>
         <translation>Couleur</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="94"/>
+        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="85"/>
         <source>Position</source>
         <translation>Position</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="100"/>
+        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="88"/>
         <source>Conversion failed</source>
         <translation>Echec de convertion</translation>
     </message>
@@ -352,12 +356,12 @@
 <context>
     <name>Actions::VariableInstance</name>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variableinstance.h" line="83"/>
+        <location filename="../actions/actionpackinternal/actions/variableinstance.h" line="82"/>
         <source>Cannot evaluate the value as an integer</source>
         <translation>Impossible d&apos;évaluer la valeur en tant que nombre entier</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variableinstance.h" line="94"/>
+        <location filename="../actions/actionpackinternal/actions/variableinstance.h" line="93"/>
         <source>Cannot evaluate the value as a floating number</source>
         <translation>Impossible d&apos;évaluer la valeur en tant que nombre décimal</translation>
     </message>
@@ -411,12 +415,12 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../actions/actionpackinternal/actions/codedefinition.h" line="50"/>
+        <location filename="../actions/actionpackinternal/actions/codedefinition.h" line="48"/>
         <source>Code</source>
         <translation>Code</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/codedefinition.h" line="53"/>
+        <location filename="../actions/actionpackinternal/actions/codedefinition.h" line="51"/>
         <source>Evaluates some code</source>
         <translation>Évalue du code</translation>
     </message>
@@ -429,82 +433,82 @@
         <translation type="obsolete">Quitte Actionaz</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/gotodefinition.h" line="49"/>
+        <location filename="../actions/actionpackinternal/actions/gotodefinition.h" line="47"/>
         <source>Goto</source>
         <translation>Aller à</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/gotodefinition.h" line="52"/>
+        <location filename="../actions/actionpackinternal/actions/gotodefinition.h" line="50"/>
         <source>Go to a script line</source>
         <translation>Va à une ligne du script</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="58"/>
+        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="55"/>
         <source>Loop</source>
         <translation>Boucle</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="61"/>
+        <location filename="../actions/actionpackinternal/actions/loopdefinition.h" line="58"/>
         <source>Go to a script line a specific number of times</source>
         <translation>Va à une ligne du script un certain nombre de fois</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/noopdefinition.h" line="45"/>
+        <location filename="../actions/actionpackinternal/actions/noopdefinition.h" line="44"/>
         <source>No-op</source>
         <translation>Aucune opération</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/noopdefinition.h" line="48"/>
+        <location filename="../actions/actionpackinternal/actions/noopdefinition.h" line="47"/>
         <source>Does nothing</source>
         <translation>Ne fait rien</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="63"/>
+        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="60"/>
         <source>Pause</source>
         <translation>Pause</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="66"/>
+        <location filename="../actions/actionpackinternal/actions/pausedefinition.h" line="63"/>
         <source>Pauses the script execution</source>
         <translation>Met en pause l&apos;exécution du script</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/stopdefinition.h" line="45"/>
+        <location filename="../actions/actionpackinternal/actions/stopdefinition.h" line="44"/>
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/stopdefinition.h" line="48"/>
+        <location filename="../actions/actionpackinternal/actions/stopdefinition.h" line="47"/>
         <source>Stop the script execution</source>
         <translation>Stoppe l&apos;exécution du script</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="63"/>
+        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="58"/>
         <source>Time condition</source>
         <translation>Condition temporelle</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="66"/>
+        <location filename="../actions/actionpackinternal/actions/timeconditiondefinition.h" line="61"/>
         <source>Check the current date time and do some action</source>
         <translation>Vérifie la date actuelle et effectue une action</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="73"/>
+        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="67"/>
         <source>Variable condition</source>
         <translation>Condition de variable</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="76"/>
+        <location filename="../actions/actionpackinternal/actions/variableconditiondefinition.h" line="70"/>
         <source>Check the value of a variable and do some action</source>
         <translation>Vérifie la valeur d&apos;une variable et effectue une action</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="103"/>
+        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="91"/>
         <source>Variable</source>
         <translation>Variable</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="106"/>
+        <location filename="../actions/actionpackinternal/actions/variabledefinition.h" line="94"/>
         <source>Set the value of a variable</source>
         <translation>Change la valeur d&apos;une variable</translation>
     </message>
@@ -537,12 +541,12 @@
         <translation type="obsolete">Contient</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="58"/>
+        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="55"/>
         <source>Console</source>
         <translation>Console</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="61"/>
+        <location filename="../actions/actionpackinternal/actions/consoledefinition.h" line="58"/>
         <source>Write an entry in the console</source>
         <translation>Écrit une entrée dans la console</translation>
     </message>
@@ -557,43 +561,43 @@
         <translation type="obsolete">Quitte Actionaz</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/beginproceduredefinition.h" line="50"/>
+        <location filename="../actions/actionpackinternal/actions/beginproceduredefinition.h" line="48"/>
         <source>Begin procedure</source>
         <translation>Début de procédure</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/beginproceduredefinition.h" line="53"/>
+        <location filename="../actions/actionpackinternal/actions/beginproceduredefinition.h" line="51"/>
         <source>Declares a new procedure</source>
         <translation>Déclare une nouvelle procédure</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/callproceduredefinition.h" line="49"/>
+        <location filename="../actions/actionpackinternal/actions/callproceduredefinition.h" line="47"/>
         <source>Call procedure</source>
         <translation>Appel de procédure</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/callproceduredefinition.h" line="52"/>
+        <location filename="../actions/actionpackinternal/actions/callproceduredefinition.h" line="50"/>
         <source>Calls a procedure</source>
         <translation>Appelle une procédure</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/endproceduredefinition.h" line="45"/>
+        <location filename="../actions/actionpackinternal/actions/endproceduredefinition.h" line="44"/>
         <source>End procedure</source>
         <translation>Fin de procédure</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/endproceduredefinition.h" line="48"/>
+        <location filename="../actions/actionpackinternal/actions/endproceduredefinition.h" line="47"/>
         <source>Ends a procedure</source>
         <translation>Termine une procédure</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/exitdefinition.h" line="45"/>
+        <location filename="../actions/actionpackinternal/actions/exitdefinition.h" line="44"/>
         <source>Exit Actiona</source>
         <comment>action name: to exit</comment>
         <translation>Quitter Actiona</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackinternal/actions/exitdefinition.h" line="48"/>
+        <location filename="../actions/actionpackinternal/actions/exitdefinition.h" line="47"/>
         <source>Exit Actiona</source>
         <comment>action description: this exits</comment>
         <translation>Quitte Actiona</translation>
