@@ -18,8 +18,7 @@
 	Contact : jmgr@jmgr.info
 */
 
-#ifndef TOOLS_GLOBAL_H
-#define TOOLS_GLOBAL_H
+#pragma once
 
 #include <QtGlobal>
 
@@ -29,4 +28,3 @@
 #  define TOOLSSHARED_EXPORT Q_DECL_IMPORT
 #endif
 
-#endif // TOOLS_GLOBAL_H
